export type TwinUpdate = {
    version: number;
    properties: {
        reported: {
            [key: string]: any;
        };
        desired: {
            [key: string]: any;
        };
    };
};
export type DeviceId = string;
type GrantRequestBase<T> = {
    deviceId: string;
    sessionId: string;
} & T;
export type TelemetryGrantRequest = GrantRequestBase<{
    type: 'telemetry';
    telemetryKey?: string | null;
}>;
export type DeviceTwinGrantRequest = GrantRequestBase<{
    type: 'deviceTwin';
}>;
export type ConnectionStateGrantRequest = GrantRequestBase<{
    type: 'connectionState';
}>;
export type DesiredPropertyGrantRequest = GrantRequestBase<{
    type: 'desiredProperties';
}>;
export type DirectMethodGrantRequest = GrantRequestBase<{
    type: 'directMethod';
    directMethodName: string | null;
}>;
export type D2CMessageGrantRequest = GrantRequestBase<{
    type: 'd2cMessages';
}>;
export type GrantRequest = TelemetryGrantRequest | DeviceTwinGrantRequest | ConnectionStateGrantRequest | DesiredPropertyGrantRequest | DirectMethodGrantRequest | D2CMessageGrantRequest;
type SubscriptionRequestBase<T> = {
    deviceId: string;
    sessionId: string;
} & T;
export type TelemetrySubscriptionRequest = SubscriptionRequestBase<{
    type: 'telemetry';
    telemetryKey: string | null;
}>;
export type DeviceTwinSubscriptionRequest = SubscriptionRequestBase<{
    type: 'deviceTwin';
}>;
export type ConnectionStateSubscriptionRequest = SubscriptionRequestBase<{
    type: 'connectionState';
}>;
export type D2CMessageSubscriptionRequest = SubscriptionRequestBase<{
    type: 'd2cMessages';
}>;
export type SubscriptionRequest = TelemetrySubscriptionRequest | DeviceTwinSubscriptionRequest | ConnectionStateSubscriptionRequest | D2CMessageSubscriptionRequest;
export type ConnectionState = {
    connected: boolean;
};
export type MessageBase<T> = {
    deviceId: DeviceId;
    timestamp: string;
} & T;
export type TelemetryMessage = MessageBase<{
    telemetry: Record<string, unknown>;
}>;
export type ConnectionStateMessage = MessageBase<{
    connectionState: boolean;
}>;
export type DeviceTwinMessage = MessageBase<{
    deviceTwin: TwinUpdate;
}>;
export type D2CMessage = MessageBase<{
    message: Record<string, unknown>;
}>;
export type Message = TelemetryMessage | ConnectionStateMessage | DeviceTwinMessage | D2CMessage;
export type IoTHubResponse = {
    status: number;
    payload: unknown;
};
export type LogLevel = 'error' | 'warn' | 'info' | 'verbose' | 'debug';
export type ParsedConnectionString = {
    Endpoint: string;
    SharedAccessKey: string;
};
export declare function parseConnectionString(connectionString: string): ParsedConnectionString;
export declare const isGrantRequest: (request: unknown) => request is GrantRequest;
export declare const isTelemetryGrantRequest: (request: unknown) => request is TelemetryGrantRequest;
export declare const isDeviceTwinGrantRequest: (request: unknown) => request is DeviceTwinGrantRequest;
export declare const isConnectionStateGrantRequest: (request: unknown) => request is ConnectionStateGrantRequest;
export declare const isDesiredPropertyGrantRequest: (request: unknown) => request is DesiredPropertyGrantRequest;
export declare const isDirectMethodGrantRequest: (request: unknown) => request is DirectMethodGrantRequest;
export declare const isD2CMessageGrantRequest: (request: unknown) => request is D2CMessageGrantRequest;
export type LastValueResponse<T> = {
    deviceId: string;
    data: T;
    timestamp: string;
};
export type CachedValueType = string | boolean | number | Record<string, unknown>;
export type LastValueObj<T extends CachedValueType> = {
    value: T;
    timestamp: string;
};
export type LastValueTelemetryResponse = LastValueResponse<Record<string, LastValueObj<CachedValueType>>>;
export type LastValueDeviceTwinResponse = LastValueResponse<TwinUpdate>;
export type LastValueConnectionStateResponse = LastValueResponse<boolean>;
export type LastValuesBodyConfig = {
    connectionState?: boolean;
    deviceTwin?: boolean;
    telemetry?: string[];
};
export type LastValuesRequestBody = Record<string, LastValuesBodyConfig>;
export {};
